# Localizations []({{ site.repo }}/blob/develop/docs/_i18n/{{ site.lang }}/documentation/localizations.md) ---

Nombre | Parámetro | Valor por defecto
--- | --- | ---
formatLoadingMessage | - | 'Loading, please wait…'
formatRecordsPerPage | pageNumber | '%s records per page'
formatShowingRows | pageFrom, pageTo, totalRows | 'Showing %s to %s of %s rows'
formatDetailPagination | totalRows | 'Showing %s rows'
formatSearch | - | 'Search'
formatNoMatches | - | 'No matching records found'
formatRefresh | - | 'Refresh'
formatToggle | - | 'Toggle'
formatColumns | - | 'Columns'
formatAllRows | --/td> | 'All'